{% if filetype_loop == 0 %}Association Address,Local Mode,Clock Offset,Clock Precision,Clock Reference ID,Clock State,Clock Statum,Reference Time,Root Delay,Root Dispersion
{{ to_parse_ntp.system_status.associations_address }},{{ to_parse_ntp.system_status.associations_local_mode }},{{ to_parse_ntp.system_status.clock_offset }},{{ to_parse_ntp.system_status.clock_precision }},{{ to_parse_ntp.system_status.clock_refid }},{{ to_parse_ntp.system_status.clock_state }},{{ to_parse_ntp.system_status.clock_stratum }},{{ to_parse_ntp.system_status.reference_time }},{{ to_parse_ntp.system_status.root_delay }},{{ to_parse_ntp.system_status.root_dispersion }}
{% else %}{% filetype_loop == 1 %}
# Learn NTP Clock State
| Association Address | Local Mode | Clock Offset | Clock Precision | Clock Reference ID | Clock State | Clock Statum | Reference Time | Root Delay | Root Dispersion |
| ------------------- | ---------- | ------------ | --------------- | ------------------ | ----------- | ------------ | -------------- | ---------- | --------------- |
| {{ to_parse_ntp.system_status.associations_address }} | {{ to_parse_ntp.system_status.associations_local_mode }} | {{ to_parse_ntp.system_status.clock_offset }} | {{ to_parse_ntp.system_status.clock_precision }} | {{ to_parse_ntp.system_status.clock_refid }} | {{ to_parse_ntp.system_status.clock_state }} | {{ to_parse_ntp.system_status.clock_stratum }} | {{ to_parse_ntp.system_status.reference_time }} | {{ to_parse_ntp.system_status.root_delay }} | {{ to_parse_ntp.system_status.root_dispersion }} |
{% else %}{% if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Learn NTP Clock State</h1>
<table id = "ntp">
  <tr>
    <th>Association Address</th>
    <th>Local Mode</th>
    <th>Clock Offset</th>
    <th>Clock Precision</th>
    <th>Clock Reference ID</th>
    <th>Clock State</th>
    <th>Clock Statum</th>
    <th>Reference Time</th>
    <th>Root Delay</th>
    <th>Root Dispersion</th>  
  </tr>
  <tr>
    <td>{{ to_parse_ntp.system_status.associations_address }}</td>
    <td>{{ to_parse_ntp.system_status.associations_local_mode }}</td>
    <td>{{ to_parse_ntp.system_status.clock_offset }}</td>
    <td>{{ to_parse_ntp.system_status.clock_precision }}</td>
    <td>{{ to_parse_ntp.system_status.clock_refid }}</td>
    <td>{{ to_parse_ntp.system_status.clock_state }}</td>
    <td>{{ to_parse_ntp.system_status.clock_stratum }}</td>
    <td>{{ to_parse_ntp.system_status.reference_time }}</td>
    <td>{{ to_parse_ntp.system_status.root_delay }}</td>
    <td>{{ to_parse_ntp.system_status.root_dispersion }}</td>
  </tr> 
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#ntp thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#ntp thead');

    var table = $('#ntp').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>{% else %}
# Learn NTP
## Associations
### Address: {{ to_parse_ntp.system_status.associations_address }}
### Local Mode: {{ to_parse_ntp.system_status.associations_local_mode }}
## Clock
### Offset: {{ to_parse_ntp.system_status.clock_offset }}
### Precision: {{ to_parse_ntp.system_status.clock_precision }}
### Reference
#### ID: {{ to_parse_ntp.system_status.clock_refid }}
#### Time {{ to_parse_ntp.system_status.reference_time }}
### State: {{ to_parse_ntp.system_status.clock_state }}
### Statum: {{ to_parse_ntp.system_status.clock_stratum }}
## Root
### Delay: {{ to_parse_ntp.system_status.root_delay }}
### Dispersion {{ to_parse_ntp.system_status.root_dispersion }}
{% endif %}{% endif %}{% endif %}